# Multi Image Picker plugin for Flutter

A Flutter plugin for iOS and Android for picking multiple images from the image library,
and taking new pictures with the camera.

*Note*: This plugin is still under development, and some APIs might not be available yet. This plugin is inspired from   [image_picker](https://pub.dartlang.org/packages/image_picker#-readme-tab-). The iOS version is okay (using [ELCImagePickerController](https://github.com/B-Sides/ELCImagePickerController)), but the android version is still on progress on its Custom Gallery

## Installation

First, add `multi_image_picker` as a [dependency in your pubspec.yaml file](https://flutter.io/platform-plugins/).

### iOS

Add the following keys to your _Info.plist_ file, located in `<project root>/ios/Runner/Info.plist`:

* `NSPhotoLibraryUsageDescription` - describe why your app needs permission for the photo library. This is called _Privacy - Photo Library Usage Description_ in the visual editor.
* `NSCameraUsageDescription` - describe why your app needs access to the camera. This is called _Privacy - Camera Usage Description_ in the visual editor.
* `NSMicrophoneUsageDescription` - describe why your app needs access to the microphone, if you intend to record videos. This is called _Privacy - Microphone Usage Description_ in the visual editor.

### Android

No configuration required - the plugin should work out of the box.

### Example

``` dart
import 'package:multi_image_picker/multi_image_picker.dart';

class MyHomePage extends StatefulWidget {
@override
_MyHomePageState createState() => new _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
List<File> _images;

Future getImages() async {
var images = await MultiImagePicker.pickImages(source: ImageSource.gallery);

setState(() {
_images = images;
});
}

@override
Widget build(BuildContext context) {
return new Scaffold(
appBar: new AppBar(
title: new Text('Image Picker Example'),
),
body: new Center(
child: _images == null
? new Text('No image selected.')
: (_images.length == 1)
? //for pickImage case (1 image)
new Image.file(_images[0])
: ListView(
children: _images.map((file) {
return Image.file(file);
}).toList(),
)),
floatingActionButton: new FloatingActionButton(
onPressed: getImages,
tooltip: 'Pick Image',
child: new Icon(Icons.add_a_photo),
),
);
}
}
```

